//
// file: shatcompare.C
//
// macros:
//   shatcompare - plot final state invariant mass distribution
//                 for several different files for the W' analysis.
//
// Author: Reinhard Schwienhorst
//
// Modifications:
//

//----------------------------------------------------------------------------
// 
//
// plot something
int shatcompare()
{

  // the input files are not normalized, do that here
  const float XSNormsm=0.88/189222. ; 
  const float XSNormqq=2.79/128289.;
  const float XSNormlq=2.10/128289.;
  const float XSNormlqsm=(2.10+0.88)/192399.;
  const float XSNormqqsm=(2.79+0.88)/124904. ; //5.07/124904.; 
  const float XSNormleft=2.17/60355.; //*2./1.25; // we need the additional factor for norm 

  // for 800GeV files:
  //const float XSNormqq=  0.506/158973.; //   0.34/158973.;
  //const float XSNormleft= 1.056/86668.;  // new norm: CompHEP * 2 // 0.65/86668.*2./1.25; //* 39./26.;
  //const float XSNormlqsm=  1.338/142894.;  // new norm: CompHEP * 2 // (0.26+0.88)/142894.;
  //const float XSNormqqsm=  1.456/171327.;  // new norm: CompHEP * 2 // (0.34+0.88)/171327.;
  

  gROOT->LoadMacro("../rootutils/CombineHistos.C");

  TString plotTargetDir("../../histograms");
  TString suffix(".eps");


  TString cname="shat_compare";
  //cname+=name+PlotChoice();

  TString HistoFilesm="../../scripts/tb_a_1000_e.root";
  TString HistoFileqq="../../scripts/600_right_qq.root";
  TString HistoFileqqsm="../../scripts/600_right_qqsm.root";
  TString HistoFilelqsm="../../scripts/600_right_lq.root";
  TString HistoFileleft="../../scripts/600_left_lq.root";
  TFile  *filesm=new TFile(HistoFilesm);
  TFile  *fileqq=new TFile(HistoFileqq);
  TFile  *fileqqsm=new TFile(HistoFileqqsm);
  TFile  *filelqsm=new TFile(HistoFilelqsm);
  TFile  *fileleft=new TFile(HistoFileleft);
  TDirectory *dsm = (TDirectory*)filesm->Get("02_Histogramming_Parton/inclusive");
  TDirectory *dqq = (TDirectory*)fileqq->Get("02_Histogramming_Parton/inclusive");
  TDirectory *dqqsm = (TDirectory*)fileqqsm->Get("02_Histogramming_Parton/inclusive");
  TDirectory *dlqsm = (TDirectory*)filelqsm->Get("02_Histogramming_Parton/inclusive");
  TDirectory *dleft = (TDirectory*)fileleft->Get("02_Histogramming_Parton/inclusive");

  TH1F *temphist;

  TString legends[21],legendsright[21];
  Int_t palette[21]={1,2,4, 3,1,4, 4,1,2, 3,1,2, 37,1,2, 1,2,4};
  Int_t styles[21]= {1,11,3,5, 2,1,3, 3,1,2, 4,1,2,  1,2,3, 1,2,3};
  TObjArray histosleft,histosright;
  int nplotsleft=0,nplotsright=0;

  int rebin=5;
  int drawLine=0;       // draw histograms, no line
  bool normalize=false;

  // now add the histograms to the array:
  temphist=(TH1F*) (dsm->Get("InitialWM"))->Clone();
  temphist->Scale(XSNormsm*1000./temphist->GetBinWidth(1)/((double)rebin));
  histosleft.Add(temphist);
  legends[nplotsleft]="SM";
  nplotsleft++;

  // now add the histograms to the array:
  // note this is right-handed lq!!! this is qq with lq normalization
  temphist=(TH1F*) (dqq->Get("InitialWM"))->Clone();
  temphist->Scale(XSNormlq*1000./temphist->GetBinWidth(1)/((double)rebin));
  histosleft.Add(temphist);
  legends[nplotsleft]="W'_{R}";
  nplotsleft++;

  // now add the histograms to the array:
  temphist=(TH1F*) (dleft->Get("InitialWM"))->Clone();
  temphist->Scale(XSNormleft*1000./temphist->GetBinWidth(1)/((double)rebin));
  histosleft.Add(temphist);
  legends[nplotsleft]="SM+W'_{L}";
  nplotsleft++;

  //
  // second plot
  // now add the histograms to the array:
  temphist=(TH1F*) (dlqsm->Get("InitialWM"))->Clone();
  temphist->Scale(XSNormlqsm*1000./temphist->GetBinWidth(1)/((double)rebin));
  histosright.Add(temphist);
  legendsright[nplotsright]="(SM+W'_{R})#rightarrow l,q";
  nplotsright++;

  // now add the histograms to the array:
  temphist=(TH1F*) (dqqsm->Get("InitialWM"))->Clone();
  temphist->Scale(XSNormqqsm*1000./temphist->GetBinWidth(1)/((double)rebin));
  histosright.Add(temphist);
  legendsright[nplotsright]="(SM+W'_{R})#rightarrow only q";
  nplotsright++;

  // now add the histograms to the array:
  temphist=(TH1F*) (dqq->Get("InitialWM"))->Clone();
  temphist->Scale(XSNormqq*1000./temphist->GetBinWidth(1)/((double)rebin));
  histosright.Add(temphist);
  legendsright[nplotsright]="W'_{R}#rightarrow only q";
  nplotsright++;


 
 
  // change the y axis title in case the x axis title contains the sub-string []
  TString ytitle="d#sigma/dM #times B(W'#rightarrow tb) [fb/30 GeV]";
  TString xtitle="M [GeV]";
  
  int legendCorner=10;
  int smoothen=0;
  double xmin=0.;
  double xmax=800.;
  double xmin_cutoff=5.;
  double ymin=0.01;
  double ymax=60.;

  TCanvas *c1 = new TCanvas(cname.Data(), "",50,44,600,500);
  // make more space for the Y-axis title
  c1->SetLeftMargin( .21); // default is 10%
  c1->SetBottomMargin(0.15);

  CombineHistos(histosleft,legends,"",xtitle.Data(),ytitle.Data(),palette,styles,legendCorner,smoothen,rebin,drawLine,normalize,xmin,xmax,xmin_cutoff,ymin,ymax);

  // add some text
  TLatex *t1 = new TLatex();
  t1->SetTextFont(62);
  t1->SetTextColor(1);
  t1->SetNDC();
  t1->SetTextAlign(12);
  t1->SetTextSize(0.06);
  //t1->DrawLatex(0.24,0.87,"(a)");
  t1->DrawLatex(0.84,0.87,"(a)");

  c1->SetLogy();
  // and write the plot to file
  c1->SaveAs(plotTargetDir+"/"+cname+suffix);

  TCanvas *c2 = new TCanvas((cname+"_right").Data(), "",50,44,600,500);
  // make more space for the Y-axis title
  c2->SetLeftMargin( .21); // default is 10%
  c2->SetBottomMargin(0.15);


  // also make the second plot
  CombineHistos(histosright,legendsright,"",xtitle.Data(),ytitle.Data(),palette,styles,legendCorner,smoothen,rebin,drawLine,normalize,xmin,xmax,xmin_cutoff,ymin,ymax);

  // add some text
  t1->DrawLatex(0.84,0.87,"(b)");


  c2->SetLogy();
  // and write the plot to file
  c2->SaveAs(plotTargetDir+"/"+cname+"_right"+suffix);

  //cout<<"end of plotHistogram"<<endl;
  return 0;
} // end of plotHistogram

