/******************************************************************************
 * CutNJets.hpp                                                               *
 *                                                                            *
 * Cuts on number of jets in an event                                         *
 *                                                                            *
 * Derived from HistoCut which is in turn derived from BaseCut                *
 *                                                                            *
 * Public Member Functions of AnalysisMain class                              *
 *    CutNJets()                        -- Parameterized Constructor          *
 *    ~CutNJets()                       -- Destructor                         *
 *    BookHistogram()                   -- Book histograms                    *
 *    Apply()                           -- Apply cuts and fill histograms     *
 *    GetCutName()                      -- Returns "CutNJets"                 *
 *                                                                            *
 * Private Data Members of AnalysisMain class                                 *
 *    myTH1F* _hNJetsBefore              -- Hist of Num of jets before cuts   *
 *    myTH1F* _hNJetsAfter               -- Hist of Num of jets before cuts   *
 *                                                                            *
 * History                                                                    *
 *       7 Nov 2006 - Created by R. Schwienhorst for ATLAS                    *
 *      10 Nov 2006 - Modified by P. Ryan - cleanup and reorganized           *
 *****************************************************************************/

#ifndef CutNJets_h
#define CutNJets_h

#include "single_top_analysis/HistoCut.hpp"
#include "single_top_analysis/EventContainer.hpp"

#include <string>
#include <vector>
#include <sstream>

using namespace std;


class CutNJets : public HistoCut 
{

public:

  // Parameterized Constructor
  CutNJets(EventContainer *obj);
  
  // Destructor
  ~CutNJets();

  // Get the name of describing the cut
  inline std::string GetCutName (void) { return "CutNJets"; };

  // Book Histograms
  void BookHistogram();

  // Apply cut and fill histogram
  Bool_t Apply();


private:

  // Histograms
  myTH1F* _hNJetsBefore;    // Histogram number of jets before the cut
  myTH1F* _hNJetsAfter;     // Histogram number of jets after the cut

  // Cut parameters
  Int_t _nJetsMin;           // Minimum number of jets to require
  Int_t _nJetsMax;           // Maximum number of jets allowed

};


#endif







