///
/// BaseCut.cpp
///
///  A few files required to make the base cut stuff work correctly
///
#include "single_top_analysis/BaseCut.hpp"

#include "TROOT.h"

#include <iostream>

ClassImp(BaseCut);

static TDirectory *g_bc_dir = 0;

	///
	/// SetName
	///
	///  Remember the name, and make sure to install ourselves in the base cut
	/// directory
	///
void BaseCut::SetName (const char *name)
{
  TNamed::SetName (name);

  ///
  /// Make sure the BaseCuts directory is there and ready to go!
  ///

  if (g_bc_dir == 0) {
    g_bc_dir = gROOT->mkdir ("BaseCuts");
  }

  ///
  /// Ok -- save this guy to this directory
  ///

  g_bc_dir->Append (this);
}

///
/// GetBaseCut
///
///  Lift this base cut from the directory. Return null if it isn't there
///
BaseCut *BaseCut::GetBaseCut (const std::string &name)
{
  BaseCut *c = 0;
  if (g_bc_dir == 0) {
    c = 0;
  } else {
    c = static_cast<BaseCut*>(g_bc_dir->FindObject(name.c_str()));
  }

  if (c == 0) {
    std::cout << "ERROR: Base cut " << name << " has never been heard of!" << std::endl;
  }
  return c;
}
